@@ -1,7 +1,7 @@
 """html2text: Turn HTML into equivalent Markdown-structured text."""
-__version__ = "2.24"
+__version__ = "2.29"
 __author__ = "Aaron Swartz (me@aaronsw.com)"
-__copyright__ = "(C) 2004 Aaron Swartz. GNU GPL 2."
+__copyright__ = "(C) 2004-2007 Aaron Swartz. GNU GPL 2."
 __contributors__ = ["Martin 'Joey' Schulze", "Ricardo Reyes"]
 
 # TODO:
@@ -215,6 +215,9 @@ class _html2text(sgmllib.SGMLParser):
 		if tag in ["head", "style", 'script']: 
 			if start: self.quiet += 1
 			else: self.quiet -= 1
+
+		if tag in ["body"]:
+		    self.quiet = 0 # sites like 9rules.com never close <head>
 		
 		if tag == "blockquote":
 			if start: 
@@ -275,7 +278,7 @@ class _html2text(sgmllib.SGMLParser):
 		if tag == 'dt' and not start: self.pbr()
 		if tag == 'dd' and start: self.o('    ')
 		if tag == 'dd' and not start: self.pbr()
-
+		
 		if tag in ["ol", "ul"]:
 			if start:
 				self.list.append({'name':tag, 'num':0})
@@ -298,7 +301,8 @@ class _html2text(sgmllib.SGMLParser):
 			else:
 				self.pbr()
 		
-		if tag in ['tr']: self.pbr()
+		if tag in ["table", "tr"] and start: self.p()
+		if tag == 'td': self.pbr()
 		
 		if tag == "pre":
 			if start:
@@ -378,8 +382,10 @@ class _html2text(sgmllib.SGMLParser):
 		self.o(data, 1)
 	
 	def unknown_decl(self, data): pass
-		
-def html2text_file(html, out=sys.stdout.write):
+
+def wrapwrite(text): sys.stdout.write(text.encode('utf8'))
+
+def html2text_file(html, out=wrapwrite):
 	h = _html2text(out)
 	h.feed(html)
 	h.feed("")
@@ -392,7 +398,16 @@ if __name__ == "__main__":
 	if sys.argv[1:]:
 		arg = sys.argv[1]
 		if arg.startswith('http://'):
-			data = urllib.urlopen(arg).read()
+			j = urllib.urlopen(arg)
+			try:
+				from feedparser import _getCharacterEncoding as enc
+			except ImportError:
+			       enc = lambda x, y: ('utf-8', 1)
+			text = j.read()
+			encoding = enc(j.headers, text)[0]
+			if encoding == 'us-ascii': encoding = 'utf-8'
+			data = html2text_file(text.decode(encoding))
+
 		else:
 			data = open(arg, 'r').read()
 	else:
